@@ -43,7 +43,6 @@ static void defaultConfig(void)
     ffOptionsInitGeneral(&instance.config.general);
     ffOptionsInitModules(&instance.config.modules);
     ffOptionsInitDisplay(&instance.config.display);
-    ffOptionsInitLibrary(&instance.config.library);
 }
 
 void ffInitInstance(void)
@@ -54,10 +53,6 @@ void ffInitInstance(void)
     #else
         // Never use `setlocale(LC_ALL, "")`
         setlocale(LC_TIME, "");
-        setlocale(LC_NUMERIC, "");
-        #ifdef LC_MESSAGES
-            setlocale(LC_MESSAGES, "");
-        #endif
     #endif
 
     initState(&instance.state);
@@ -152,7 +147,6 @@ static void destroyConfig(void)
     ffOptionsDestroyGeneral(&instance.config.general);
     ffOptionsDestroyModules(&instance.config.modules);
     ffOptionsDestroyDisplay(&instance.config.display);
-    ffOptionsDestroyLibrary(&instance.config.library);
 }
 
 static void destroyState(void)
@@ -248,9 +242,12 @@ void ffListFeatures(void)
         #if FF_HAVE_DDCUTIL
             "libddcutil\n"
         #endif
-        #if FF_HAVE_ELF
+        #if FF_HAVE_ELF || __sun || __FreeBSD__
             "libelf\n"
         #endif
+        #if FF_HAVE_LIBZFS
+            "libzfs\n"
+        #endif
         #if FF_HAVE_DIRECTX_HEADERS
             "Directx Headers\n"
         #endif
