@@ -55,28 +55,28 @@ static void* libraryLoad(const char* path, int maxVersion)
     return result;
 }
 
-void* ffLibraryLoad(const FFstrbuf* userProvidedName, ...)
+void* ffLibraryLoad(const char* path, int maxVersion, ...)
 {
-    if(userProvidedName != NULL && userProvidedName->length > 0)
-        return dlopen(userProvidedName->chars, FF_DLOPEN_FLAGS);
+    void* result = libraryLoad(path, maxVersion);
 
-    va_list defaultNames;
-    va_start(defaultNames, userProvidedName);
-
-    void* result = NULL;
-
-    while(result == NULL)
+    if (!result)
     {
-        const char* path = va_arg(defaultNames, const char*);
-        if(path == NULL)
-            break;
+        va_list defaultNames;
+        va_start(defaultNames, maxVersion);
 
-        int maxVersion = va_arg(defaultNames, int);
-        result = libraryLoad(path, maxVersion);
+        do
+        {
+            const char* pathRest = va_arg(defaultNames, const char*);
+            if(pathRest == NULL)
+                break;
+
+            int maxVersionRest = va_arg(defaultNames, int);
+            result = libraryLoad(pathRest, maxVersionRest);
+        } while (!result);
+
+        va_end(defaultNames);
     }
 
-    va_end(defaultNames);
-
     return result;
 }
 
